@@ -19,7 +19,7 @@ NEW_PPT = f'{parent}\\QUOTE_NEW.pptm'
 prs = Presentation(OLD_PPT)
 
 QUOTESContent = File(QUOTES, enc=1).read()
-QUOTESList = QUOTESContent.split("\n\n")
+QUOTESList = QUOTESContent.decode(encoding="utf-8").split("\n\n")
 
 #DUPLICATE PPT SLIDE FOR EVERY 
 # for i in range (1,len(QUOTESList)):
